require "mkmf"

def have_librarys(*lib)
  printf "checking librarys lib%s... ", lib.join(", lib")
  STDOUT.flush

  libs = "-l" + lib.join(" -l") + " " + $libs
  r = try_link(<<"SRC", libs)
int main() { return 0; }
SRC
  unless r
    print "no\n"
    return false
  end

  $libs = libs
  print "yes\n"
  return true
end


case RUBY_PLATFORM
when /linux/
  if with_config("ifort")
    dir_config("--with-ifort","/usr/include","/opt/intel/lib/intel64")
#    if ! have_librarys("ifcore") then
    if ! have_librarys("ifcore", "imf", "intlc") then
      warn "cannot find library file for ifort\n"
      warn "ruby extconf.rb --with-ifort-lib=(path of libifcore.so)\n"
      exit 1
    end
#    have_librarys("svml")
    have_librarys("svml","guide")
    $CPPFLAGS = "-DIFORT"
  elsif with_config("ffc32")
    dir_config("--with-ffc","/usr/FFC/include","/usr/FFC/lib")
    if ! have_librarys("fj9f6","fj9i6","fj9e6","fccx86_6a") then
      warn "cannot find library file for ffc32\n"
      warn "ruby extconf.rb --with-ffc32-lib=(path of libfj9f6.so)\n"
      exit 1
    end
    $CPPFLAGS = "-DFFC32"
  elsif with_config("ffc64")
    dir_config("--with-ffc64","/usr/include","/usr/lib")
    if ! have_librarys("fj90f", "fj90i", "rt", "elf")
      warn "cannot find library file for ffc64\n"
      warn "ruby extconf.rb --with-ffc64-lib=(path of libfj90f.so)\n"
      exit 1
    end
    $CPPFLAGS = "-DFFC64"
  elsif with_config("gfortran")
    dir_config("--with-gfortran")
    if ! have_librarys("gfortran") then
      warn "cannot find library file for gfortran\n"
      warn "ruby extconf.rb --with-gfortran-lib=(path of libgfortran.so)\n"
      exit 1
    end
    $CPPFLAGS = "-DGFORTRAN"
  else
      warn "at this moment, only ifort, ffc and gfortran are supported\n"
      warn "ruby extconf.rb --with-ifort, --with-ffc32, --with-ffc64, or --with-gfortran\n"
      exit 1
  end

else
  warn "unsuported platform: "+RUBY_PLATFORM
  exit 1
end

unless find_header("narray.h",Config::CONFIG["archdir"],Config::CONFIG["sitearchdir"])
  warn "cannot find narray.h"
  exit 1
end


dir_config("--with-fftw","/usr/local/include","/usr/local/lib")
["fftw","rfftw"].each{|name|
  if str = arg_config("--#{name}-libname",false)
    name = str
  end
  have_librarys(name)
}


[["ispack","isp"], "netcdf", "gtool5", "spml"].each{|name|
  if Array===name
    libname = name[1]
    name = name[0]
  else
    libname = name
  end
  dir_config("--with-#{name}","/usr/local/include","/usr/local/lib")
  if str = arg_config("--#{name}-libname",false)
    libname = str
  end
  unless have_librarys(libname)
    warn "cannot find library file for #{name}\n"
    warn "ruby extconf.rb --with-#{name}-lib=(path of lib#{libname}.a) --#{name}-libname=(name of #{name} library)\n"
    exit 1
  end
}
name = "netcdff"
dir_config("--with-#{name}","/usr/local/include","/usr/local/lib")
have_librarys(name)

create_makefile("numru/spml")
